@@ -19,18 +19,18 @@
 #' \deqn{P(V) = V}
 #'
 #' @examples
-#' u = UniversalSet$new()
+#' u <- UniversalSet$new()
 #' print(u)
 #' u$contains(c(1, letters, TRUE, Set$new()), all = TRUE)
-#'
 #' @export
-UniversalSet <- R6::R6Class("UniversalSet", inherit = Set,
+UniversalSet <- R6::R6Class("UniversalSet",
+  inherit = Set,
   public = list(
     #' @description Create a new `UniversalSet` object.
     #' @details The Universal set is the set containing every possible element.
     #' @return A new `UniversalSet` object.
-    initialize = function(){
-      private$.properties = Properties$new(closure = "open", cardinality = Inf)
+    initialize = function() {
+      private$.properties <- Properties$new(closure = "open", cardinality = Inf)
       invisible(self)
     },
 
@@ -57,8 +57,8 @@ UniversalSet <- R6::R6Class("UniversalSet", inherit = Set,
     #' # Not equal
     #' !Set$new(1,2)$equals(Set$new(1,2))
     #' Set$new(1,2) != Set$new(1,5)
-    equals = function(x, all = FALSE){
-      ret = sapply(listify(x), getR6Class) %in% "UniversalSet"
+    equals = function(x, all = FALSE) {
+      ret <- sapply(listify(x), getR6Class) %in% "UniversalSet"
       returner(ret, all)
     },
 
@@ -95,11 +95,13 @@ UniversalSet <- R6::R6Class("UniversalSet", inherit = Set,
     #'
     #' c(Set$new(1,2,3), Set$new(1)) < Set$new(1,2,3) # not proper
     #' Set$new(1,2,3) <= Set$new(1,2,3) # proper
-    isSubset = function(x, proper = FALSE, all = FALSE){
-      x = listify(x)
-      returner(x = sapply(x, inherits, what = "Set") & sapply(x, getR6Class) != "UniversalSet" |
-                 sapply(x, getR6Class) == "UniversalSet" & !proper,
-               all = all)
+    isSubset = function(x, proper = FALSE, all = FALSE) {
+      x <- listify(x)
+      returner(
+        x = sapply(x, inherits, what = "Set") & sapply(x, getR6Class) != "UniversalSet" |
+          sapply(x, getR6Class) == "UniversalSet" & !proper,
+        all = all
+      )
     },
 
     #' @description Tests to see if \code{x} is contained in the Set.
@@ -141,15 +143,17 @@ UniversalSet <- R6::R6Class("UniversalSet", inherit = Set,
     #' s2 = s * s
     #' s2$contains(Tuple$new(2,1))
     #' c(Tuple$new(2,1), Tuple$new(1,7), 2) %inset% s2
-    contains = function(x, all = FALSE, bound = NULL){
-      returner(x = rep(TRUE, length(listify(x))),
-               all = all)
+    contains = function(x, all = FALSE, bound = NULL) {
+      returner(
+        x = rep(TRUE, length(listify(x))),
+        all = all
+      )
     },
 
     #' @description Creates a printable representation of the object.
     #' @param n numeric. Number of elements to display on either side of ellipsis when printing.
     #' @return A character string representing the object.
-    strprint = function(n = 2){
+    strprint = function(n = 2) {
       return("V")
     }
   ),
